#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for testing the fractionaloccupancycalculator

@author: mark
"""

import logging
import unittest
import solventmapcreator.solvationcalculation.fractionaloccupancycalculator as fractionaloccupancycalculator

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class FractionalOccupancyCalculatorTestCase(unittest.TestCase):
    """Test case for the fractionaloccupancycalculator script.
    """
    def setUp(self):
        """Set up for tests.
        """
    def tearDown(self):
        """Clean up after tests.
        """
    def test_calculate_fractional_occupancy_for_phase(self):
        """Test to see if expected value is returned.
        """
        expected_value = (55.35 * 4.0 /300.0) + (0.001/300)
        actual_value = fractionaloccupancycalculator.calculate_fractional_occupancy_for_phase("resources/watersolvent.xml",
                                                                                              "water", 0.001)
    def test_calculate_fractional_occupancy_contribution_from_solute(self):
        """Test to see if expected value is returned.
        """
        expected_value = 0.001/300
        actual_value = fractionaloccupancycalculator.calculate_fractional_occupancy_contribution_from_solute(0.001)
        self.assertAlmostEqual(expected_value, actual_value)
    def test_get_fractional_occupancy_for_solvent_from_file(self):
        """Test to see if fractional occupancy is as expected.
        """
        expected_value = 55.35 * 4.0 /300.0
        actual_value = fractionaloccupancycalculator.get_fractional_occupancy_for_solvent_from_file("resources/watersolvent.xml", "water")
        self.assertAlmostEqual(expected_value, actual_value)