#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for testing solvationcalculator script.

@author: mark
"""

import logging
import unittest
import numpy as np
import solventmapcreator.solvationcalculation.solvationcalculator as solvationcalculator

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

class SolvationCalculatorTestCase(unittest.TestCase):
    """Test case for the solvationcalculator script
    """
    def setUp(self):
        """Set up for tests.
        """
    def tearDown(self):
        """tear down after tests.
        """
    def test_calcluate_association_energy_matrix(self):
        """Test to see if expected matrix is produced.
        """
        expected_array = np.array([[-1.2500649680700651]])
        actual_array = solvationcalculator.calcluate_association_energy_matrix([1.0],[1.0], 298.0, 1.0, np.array([0.5, 1.0]))
        np.testing.assert_array_almost_equal(expected_array, actual_array)
        actual_array2 = solvationcalculator.calcluate_association_energy_matrix(np.array([1.0]),np.array([1.0]), 298.0, 1.0, np.array([0.5, 1.0]))
        np.testing.assert_array_almost_equal(expected_array, actual_array2)
    def test_calculate_association_energy(self):
        """Test to see if expected_value is returned.
        """
        expected_value = -1.2500649680700651
        actual_value = solvationcalculator.calculate_association_energy(1.0, 1.0,
                                                                        298.0, 1.0, np.array([0.5, 1.0]))
        self.assertAlmostEqual(expected_value, actual_value)
    def test_calculate_binding_energy(self):
        """Test to see if expected binding energy is returned
        """
        expected_value = -4.2500649680700662
        actual_value = solvationcalculator.calculate_binding_energy(1.0, 1.0, 298.0, 1.0)
        self.assertAlmostEqual(expected_value, actual_value)
    def test_calculate_solvation_energy(self):
        """Test to see if expected solvation energy is returned.
        """
        expected_value = 1.0
        actual_value = solvationcalculator.calculate_solvation_energy(0.5, np.array([0.5, 1.0]))
        self.assertAlmostEqual(expected_value, actual_value)
    def test_calculate_association_constant(self):
        """Test to see if expected value is returned.
        """
        expected_value = 3.200818570079262
        actual_value = solvationcalculator.calculate_association_constant(1.0, 1.0, 298.0)
        self.assertAlmostEqual(expected_value, actual_value)
